import React, { createContext, ReactNode, useState } from 'react';
import { Profile } from '../types';

// Interface definitions
interface IWarnings extends Document {
  text: string;
  date: Date;
  given_by: {
    _id: string;
    name: string;
  };
}

enum Role {
  Admin,
  Staff,
  User,
}

export interface IProfile {
  external_id: string;
  studentCardNumber?: string;
  roomNumber?: string;
  picture?: string;
  role: Role.Admin | Role.Staff | Role.User;
  email: string;
  name: string;
  warnings: [IWarnings] | [];
}

type Props = {
  children: ReactNode;
};

interface ContextProps {
  profile: Profile;
  setProfile: (profile: Profile) => void;
}

// Context
const initialState: Profile = {
  external_id: 'abcd',
  studentCardNumber: '1234',
  roomNumber: '104',
  picture: 'alma.jpg',
  role: Role.User,
  email: 'alma@gmail.com',
  name: 'Nagy Gizike',
  warnings: [],
};
export const userContext = createContext({} as IContextProps);
const { Provider } = userContext;

export const UserStateProvider: React.FC = ({ children }) => {
  const [profile, setProfile] = useState<Profile>(initialState);

  return <Provider value={{ profile, setProfile }}>{children}</Provider>;
};

export default { userContext, UserStateProvider };
